# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.gcs_service_account_input import GcsServiceAccountInput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.inputs.gcs_service_account.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.gcs_service_account.gcs_service_account_input_list_query_params import GcsServiceAccountInputListQueryParams


class GcsServiceAccountApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(GcsServiceAccountApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, gcs_service_account_input, **kwargs):
        # type: (GcsServiceAccountInput, dict) -> GcsServiceAccountInput
        """Create Service Account based GCS Input

        :param gcs_service_account_input: The GcsInput to be created
        :type gcs_service_account_input: GcsServiceAccountInput, required
        :return: Service Account based GCS input
        :rtype: GcsServiceAccountInput
        """

        return self.api_client.post(
            '/encoding/inputs/gcs-service-account',
            gcs_service_account_input,
            type=GcsServiceAccountInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> GcsServiceAccountInput
        """Delete Service Account based GCS Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: GcsServiceAccountInput
        """

        return self.api_client.delete(
            '/encoding/inputs/gcs-service-account/{input_id}',
            path_params={'input_id': input_id},
            type=GcsServiceAccountInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> GcsServiceAccountInput
        """List Service Account based GCS Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: GCS input
        :rtype: GcsServiceAccountInput
        """

        return self.api_client.get(
            '/encoding/inputs/gcs-service-account/{input_id}',
            path_params={'input_id': input_id},
            type=GcsServiceAccountInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (GcsServiceAccountInputListQueryParams, dict) -> GcsServiceAccountInput
        """List Service Account based GCS Inputs

        :param query_params: Query parameters
        :type query_params: GcsServiceAccountInputListQueryParams
        :return: List of GCS inputs
        :rtype: GcsServiceAccountInput
        """

        return self.api_client.get(
            '/encoding/inputs/gcs-service-account',
            query_params=query_params,
            pagination_response=True,
            type=GcsServiceAccountInput,
            **kwargs
        )



from bitmovin_api_sdk.analytics.metrics.metrics_api import MetricsApi
from bitmovin_api_sdk.analytics.metrics.max_concurrentviewers.max_concurrentviewers_api import MaxConcurrentviewersApi
from bitmovin_api_sdk.analytics.metrics.avg_concurrentviewers.avg_concurrentviewers_api import AvgConcurrentviewersApi
from bitmovin_api_sdk.analytics.metrics.avg_dropped_frames.avg_dropped_frames_api import AvgDroppedFramesApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.dolby_vision_metadata_source import DolbyVisionMetadataSource
from bitmovin_api_sdk.models.dolby_vision_profile import DolbyVisionProfile
import pprint
import six


class DolbyVisionMetadata(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 profile=None,
                 metadata_source=None,
                 metadata_input_stream_id=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, DolbyVisionProfile, DolbyVisionMetadataSource, string_types) -> None
        super(DolbyVisionMetadata, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._profile = None
        self._metadata_source = None
        self._metadata_input_stream_id = None
        self.discriminator = None

        if profile is not None:
            self.profile = profile
        if metadata_source is not None:
            self.metadata_source = metadata_source
        if metadata_input_stream_id is not None:
            self.metadata_input_stream_id = metadata_input_stream_id

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DolbyVisionMetadata, self), 'openapi_types'):
            types = getattr(super(DolbyVisionMetadata, self), 'openapi_types')

        types.update({
            'profile': 'DolbyVisionProfile',
            'metadata_source': 'DolbyVisionMetadataSource',
            'metadata_input_stream_id': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DolbyVisionMetadata, self), 'attribute_map'):
            attributes = getattr(super(DolbyVisionMetadata, self), 'attribute_map')

        attributes.update({
            'profile': 'profile',
            'metadata_source': 'metadataSource',
            'metadata_input_stream_id': 'metadataInputStreamId'
        })
        return attributes

    @property
    def profile(self):
        # type: () -> DolbyVisionProfile
        """Gets the profile of this DolbyVisionMetadata.

        Dolby Vision Profile (required)

        :return: The profile of this DolbyVisionMetadata.
        :rtype: DolbyVisionProfile
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        # type: (DolbyVisionProfile) -> None
        """Sets the profile of this DolbyVisionMetadata.

        Dolby Vision Profile (required)

        :param profile: The profile of this DolbyVisionMetadata.
        :type: DolbyVisionProfile
        """

        if profile is not None:
            if not isinstance(profile, DolbyVisionProfile):
                raise TypeError("Invalid type for `profile`, type has to be `DolbyVisionProfile`")

        self._profile = profile

    @property
    def metadata_source(self):
        # type: () -> DolbyVisionMetadataSource
        """Gets the metadata_source of this DolbyVisionMetadata.

        Dolby Vision Metadata Source (required)

        :return: The metadata_source of this DolbyVisionMetadata.
        :rtype: DolbyVisionMetadataSource
        """
        return self._metadata_source

    @metadata_source.setter
    def metadata_source(self, metadata_source):
        # type: (DolbyVisionMetadataSource) -> None
        """Sets the metadata_source of this DolbyVisionMetadata.

        Dolby Vision Metadata Source (required)

        :param metadata_source: The metadata_source of this DolbyVisionMetadata.
        :type: DolbyVisionMetadataSource
        """

        if metadata_source is not None:
            if not isinstance(metadata_source, DolbyVisionMetadataSource):
                raise TypeError("Invalid type for `metadata_source`, type has to be `DolbyVisionMetadataSource`")

        self._metadata_source = metadata_source

    @property
    def metadata_input_stream_id(self):
        # type: () -> string_types
        """Gets the metadata_input_stream_id of this DolbyVisionMetadata.

        ID of the Dolby Vision Metadata Ingest Input Stream which provides the XML Metadata file. Required if metadataSource is set to INPUT_STREAM.

        :return: The metadata_input_stream_id of this DolbyVisionMetadata.
        :rtype: string_types
        """
        return self._metadata_input_stream_id

    @metadata_input_stream_id.setter
    def metadata_input_stream_id(self, metadata_input_stream_id):
        # type: (string_types) -> None
        """Sets the metadata_input_stream_id of this DolbyVisionMetadata.

        ID of the Dolby Vision Metadata Ingest Input Stream which provides the XML Metadata file. Required if metadataSource is set to INPUT_STREAM.

        :param metadata_input_stream_id: The metadata_input_stream_id of this DolbyVisionMetadata.
        :type: string_types
        """

        if metadata_input_stream_id is not None:
            if not isinstance(metadata_input_stream_id, string_types):
                raise TypeError("Invalid type for `metadata_input_stream_id`, type has to be `string_types`")

        self._metadata_input_stream_id = metadata_input_stream_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DolbyVisionMetadata, self), "to_dict"):
            result = super(DolbyVisionMetadata, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyVisionMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.input_stream import InputStream
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.input_streams.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.encodings.input_streams.audio_mix.audio_mix_api import AudioMixApi
from bitmovin_api_sdk.encoding.encodings.input_streams.ingest.ingest_api import IngestApi
from bitmovin_api_sdk.encoding.encodings.input_streams.sidecar.sidecar_api import SidecarApi
from bitmovin_api_sdk.encoding.encodings.input_streams.concatenation.concatenation_api import ConcatenationApi
from bitmovin_api_sdk.encoding.encodings.input_streams.file.file_api import FileApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.trimming_api import TrimmingApi
from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.encodings.input_streams.captions.captions_api import CaptionsApi
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_atmos.dolby_atmos_api import DolbyAtmosApi
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_vision.dolby_vision_api import DolbyVisionApi
from bitmovin_api_sdk.encoding.encodings.input_streams.input_stream_list_query_params import InputStreamListQueryParams


class InputStreamsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(InputStreamsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.audio_mix = AudioMixApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ingest = IngestApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sidecar = SidecarApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.concatenation = ConcatenationApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.file = FileApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.trimming = TrimmingApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.subtitles = SubtitlesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.captions = CaptionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dolby_atmos = DolbyAtmosApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.dolby_vision = DolbyVisionApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> InputStream
        """Input Stream Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param input_stream_id: Id of the input stream.
        :type input_stream_id: string_types, required
        :return: Input stream
        :rtype: InputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/{input_stream_id}',
            path_params={'encoding_id': encoding_id, 'input_stream_id': input_stream_id},
            type=InputStream,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, InputStreamListQueryParams, dict) -> InputStream
        """List All Input Streams

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: InputStreamListQueryParams
        :return: List of all input streams
        :rtype: InputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=InputStream,
            **kwargs
        )



from bitmovin_api_sdk.encoding.statistics.encodings.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.statistics.encodings.live.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.encodings.live.options.options_api import OptionsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live.encoding_statistics_live_list_query_params import EncodingStatisticsLiveListQueryParams
from bitmovin_api_sdk.encoding.statistics.encodings.live.encoding_statistics_live_list_by_date_range_query_params import EncodingStatisticsLiveListByDateRangeQueryParams



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.type.dash_representation_type_response_get_query_params import DashRepresentationTypeResponseGetQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LevelH265(Enum):
    L1 = "1"
    L2 = "2"
    L2_1 = "2.1"
    L3 = "3"
    L3_1 = "3.1"
    L4 = "4"
    L4_1 = "4.1"
    L5 = "5"
    L5_1 = "5.1"
    L5_2 = "5.2"
    L6 = "6"
    L6_1 = "6.1"
    L6_2 = "6.2"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.s3_input import S3Input
from bitmovin_api_sdk.encoding.inputs.s3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.s3.s3_input_list_query_params import S3InputListQueryParams


class S3Api(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(S3Api, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, s3_input, **kwargs):
        # type: (S3Input, dict) -> S3Input
        """Create S3 Input

        :param s3_input: The S3 input to be created  The following permissions are required for S3 input:   * s3:GetObject   * s3:GetBucketLocation, 
        :type s3_input: S3Input, required
        :return: S3 input
        :rtype: S3Input
        """

        return self.api_client.post(
            '/encoding/inputs/s3',
            s3_input,
            type=S3Input,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete S3 Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the deleted input
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/inputs/s3/{input_id}',
            path_params={'input_id': input_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> S3Input
        """S3 Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: S3 input
        :rtype: S3Input
        """

        return self.api_client.get(
            '/encoding/inputs/s3/{input_id}',
            path_params={'input_id': input_id},
            type=S3Input,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (S3InputListQueryParams, dict) -> S3Input
        """List S3 Inputs

        :param query_params: Query parameters
        :type query_params: S3InputListQueryParams
        :return: List of S3 inputs
        :rtype: S3Input
        """

        return self.api_client.get(
            '/encoding/inputs/s3',
            query_params=query_params,
            pagination_response=True,
            type=S3Input,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_insights_organization_settings import AnalyticsInsightsOrganizationSettings
from bitmovin_api_sdk.models.analytics_insights_organization_settings_request import AnalyticsInsightsOrganizationSettingsRequest
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class SettingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SettingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, organization_id, **kwargs):
        # type: (string_types, dict) -> AnalyticsInsightsOrganizationSettings
        """Get the current organization settings for industry insights

        :param organization_id: Organization id
        :type organization_id: string_types, required
        :return: Analytics organization settings
        :rtype: AnalyticsInsightsOrganizationSettings
        """

        return self.api_client.get(
            '/analytics/insights/organizations/{organization_id}/settings',
            path_params={'organization_id': organization_id},
            type=AnalyticsInsightsOrganizationSettings,
            **kwargs
        )

    def update(self, organization_id, analytics_insights_organization_settings_request, **kwargs):
        # type: (string_types, AnalyticsInsightsOrganizationSettingsRequest, dict) -> AnalyticsInsightsOrganizationSettings
        """Update the organization settings for industry insights

        :param organization_id: Organization id
        :type organization_id: string_types, required
        :param analytics_insights_organization_settings_request: Organization settings to be updated
        :type analytics_insights_organization_settings_request: AnalyticsInsightsOrganizationSettingsRequest, required
        :return: Updated analytics organization settings
        :rtype: AnalyticsInsightsOrganizationSettings
        """

        return self.api_client.put(
            '/analytics/insights/organizations/{organization_id}/settings',
            analytics_insights_organization_settings_request,
            path_params={'organization_id': organization_id},
            type=AnalyticsInsightsOrganizationSettings,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.player_version import PlayerVersion
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.player.channels.versions.latest.latest_api import LatestApi


class VersionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(VersionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.latest = LatestApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, channel_name, **kwargs):
        # type: (string_types, dict) -> PlayerVersion
        """List Player Versions for Channel

        :param channel_name: Name of the channel to get the player versions for.
        :type channel_name: string_types, required
        :return: Service specific result
        :rtype: PlayerVersion
        """

        return self.api_client.get(
            '/player/channels/{channel_name}/versions',
            path_params={'channel_name': channel_name},
            pagination_response=True,
            type=PlayerVersion,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AzureSpeechToCaptionsProfanity(Enum):
    MASKED = "MASKED"
    REMOVED = "REMOVED"
    RAW = "RAW"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.cdn_usage_statistics import CdnUsageStatistics
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.statistics.cdn.usage.cdn_usage_statistics_get_query_params import CdnUsageStatisticsGetQueryParams


class UsageApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(UsageApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, query_params=None, **kwargs):
        # type: (CdnUsageStatisticsGetQueryParams, dict) -> CdnUsageStatistics
        """List CDN usage statistics within specific dates.

        :param query_params: Query parameters
        :type query_params: CdnUsageStatisticsGetQueryParams
        :return: CDN usage statistics.
        :rtype: CdnUsageStatistics
        """

        return self.api_client.get(
            '/encoding/statistics/cdn/usage',
            query_params=query_params,
            type=CdnUsageStatistics,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.live.insertable_content.insertable_content_api import InsertableContentApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.schedule.schedule_api import ScheduleApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.scheduled.scheduled_api import ScheduledApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.stop.stop_api import StopApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.insertable_content_list_query_params import InsertableContentListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamKeyStatus(Enum):
    ASSIGNED = "ASSIGNED"
    UNASSIGNED = "UNASSIGNED"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class DefaultDashManifestPeriod(object):
    @poscheck_model
    def __init__(self,
                 encoding_ids=None,
                 adaptation_sets=None):
        # type: (list[string_types], list[DefaultManifestCondition]) -> None

        self._encoding_ids = list()
        self._adaptation_sets = list()
        self.discriminator = None

        if encoding_ids is not None:
            self.encoding_ids = encoding_ids
        if adaptation_sets is not None:
            self.adaptation_sets = adaptation_sets

    @property
    def openapi_types(self):
        types = {
            'encoding_ids': 'list[string_types]',
            'adaptation_sets': 'list[DefaultManifestCondition]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'encoding_ids': 'encodingIds',
            'adaptation_sets': 'adaptationSets'
        }
        return attributes

    @property
    def encoding_ids(self):
        # type: () -> list[string_types]
        """Gets the encoding_ids of this DefaultDashManifestPeriod.

        List the encoding ids for which the conditions should apply

        :return: The encoding_ids of this DefaultDashManifestPeriod.
        :rtype: list[string_types]
        """
        return self._encoding_ids

    @encoding_ids.setter
    def encoding_ids(self, encoding_ids):
        # type: (list) -> None
        """Sets the encoding_ids of this DefaultDashManifestPeriod.

        List the encoding ids for which the conditions should apply

        :param encoding_ids: The encoding_ids of this DefaultDashManifestPeriod.
        :type: list[string_types]
        """

        if encoding_ids is not None:
            if not isinstance(encoding_ids, list):
                raise TypeError("Invalid type for `encoding_ids`, type has to be `list[string_types]`")

        self._encoding_ids = encoding_ids

    @property
    def adaptation_sets(self):
        # type: () -> list[DefaultManifestCondition]
        """Gets the adaptation_sets of this DefaultDashManifestPeriod.

        Adds an adaption set for every item to the period

        :return: The adaptation_sets of this DefaultDashManifestPeriod.
        :rtype: list[DefaultManifestCondition]
        """
        return self._adaptation_sets

    @adaptation_sets.setter
    def adaptation_sets(self, adaptation_sets):
        # type: (list) -> None
        """Sets the adaptation_sets of this DefaultDashManifestPeriod.

        Adds an adaption set for every item to the period

        :param adaptation_sets: The adaptation_sets of this DefaultDashManifestPeriod.
        :type: list[DefaultManifestCondition]
        """

        if adaptation_sets is not None:
            if not isinstance(adaptation_sets, list):
                raise TypeError("Invalid type for `adaptation_sets`, type has to be `list[DefaultManifestCondition]`")

        self._adaptation_sets = adaptation_sets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DefaultDashManifestPeriod):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.configurations_api import ConfigurationsApi
from bitmovin_api_sdk.encoding.configurations.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.configurations.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.configurations.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.configurations.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.configurations.codec_configuration_list_query_params import CodecConfigurationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.tenant_with_groups import TenantWithGroups


class TenantsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(TenantsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, organization_id, **kwargs):
        # type: (string_types, dict) -> TenantWithGroups
        """List all Tenants with their groups for a given organization

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :return: Tenants with group details
        :rtype: TenantWithGroups
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}/tenants',
            path_params={'organization_id': organization_id},
            pagination_response=True,
            type=TenantWithGroups,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.gce_account import GceAccount
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.gce.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.gce.gce_account_list_query_params import GceAccountListQueryParams


class GceApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(GceApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.regions = RegionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, gce_account, **kwargs):
        # type: (GceAccount, dict) -> GceAccount
        """Add GCE Account

        :param gce_account: The GCE Account to be added
        :type gce_account: GceAccount, required
        :return: GCE account
        :rtype: GceAccount
        """

        return self.api_client.post(
            '/encoding/infrastructure/gce',
            gce_account,
            type=GceAccount,
            **kwargs
        )

    def delete(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> GceAccount
        """Delete GCE Account

        :param infrastructure_id: Id of the GCE account
        :type infrastructure_id: string_types, required
        :return: Id of the GCE account
        :rtype: GceAccount
        """

        return self.api_client.delete(
            '/encoding/infrastructure/gce/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=GceAccount,
            **kwargs
        )

    def get(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> GceAccount
        """GCE Account Details

        :param infrastructure_id: Id of the GCE account
        :type infrastructure_id: string_types, required
        :return: GCE account
        :rtype: GceAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/gce/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=GceAccount,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (GceAccountListQueryParams, dict) -> GceAccount
        """List GCE Accounts

        :param query_params: Query parameters
        :type query_params: GceAccountListQueryParams
        :return: List of GCE accounts
        :rtype: GceAccount
        """

        return self.api_client.get(
            '/encoding/infrastructure/gce',
            query_params=query_params,
            pagination_response=True,
            type=GceAccount,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.organization import Organization
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.account.organizations.sub_organizations.organization_list_query_params import OrganizationListQueryParams


class SubOrganizationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SubOrganizationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, organization_id, query_params=None, **kwargs):
        # type: (string_types, OrganizationListQueryParams, dict) -> Organization
        """Organizations under given parent organization

        :param organization_id: ID of the parent organization
        :type organization_id: string_types, required
        :param query_params: Query parameters
        :type query_params: OrganizationListQueryParams
        :return: Sub-Organizations
        :rtype: Organization
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}/sub-organizations',
            path_params={'organization_id': organization_id},
            query_params=query_params,
            pagination_response=True,
            type=Organization,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DtsMode(Enum):
    EXPRESS_AUDIO = "EXPRESS_AUDIO"
    DIGITAL_SURROUND = "DIGITAL_SURROUND"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.response_status import ResponseStatus
from bitmovin_api_sdk.models.result_wrapper import ResultWrapper
import pprint
import six


class ResponseEnvelope(object):
    @poscheck_model
    def __init__(self,
                 request_id=None,
                 status=None,
                 data=None,
                 more=None):
        # type: (string_types, ResponseStatus, ResultWrapper, object) -> None

        self._request_id = None
        self._status = None
        self._data = None
        self._more = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if status is not None:
            self.status = status
        if data is not None:
            self.data = data
        if more is not None:
            self.more = more

    @property
    def openapi_types(self):
        types = {
            'request_id': 'string_types',
            'status': 'ResponseStatus',
            'data': 'ResultWrapper',
            'more': 'object'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'request_id': 'requestId',
            'status': 'status',
            'data': 'data',
            'more': 'more'
        }
        return attributes

    @property
    def request_id(self):
        # type: () -> string_types
        """Gets the request_id of this ResponseEnvelope.

        Unique correlation id (required)

        :return: The request_id of this ResponseEnvelope.
        :rtype: string_types
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        # type: (string_types) -> None
        """Sets the request_id of this ResponseEnvelope.

        Unique correlation id (required)

        :param request_id: The request_id of this ResponseEnvelope.
        :type: string_types
        """

        if request_id is not None:
            if not isinstance(request_id, string_types):
                raise TypeError("Invalid type for `request_id`, type has to be `string_types`")

        self._request_id = request_id

    @property
    def status(self):
        # type: () -> ResponseStatus
        """Gets the status of this ResponseEnvelope.

        Response status information (required)

        :return: The status of this ResponseEnvelope.
        :rtype: ResponseStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (ResponseStatus) -> None
        """Sets the status of this ResponseEnvelope.

        Response status information (required)

        :param status: The status of this ResponseEnvelope.
        :type: ResponseStatus
        """

        if status is not None:
            if not isinstance(status, ResponseStatus):
                raise TypeError("Invalid type for `status`, type has to be `ResponseStatus`")

        self._status = status

    @property
    def data(self):
        # type: () -> ResultWrapper
        """Gets the data of this ResponseEnvelope.

        Response information (required)

        :return: The data of this ResponseEnvelope.
        :rtype: ResultWrapper
        """
        return self._data

    @data.setter
    def data(self, data):
        # type: (ResultWrapper) -> None
        """Sets the data of this ResponseEnvelope.

        Response information (required)

        :param data: The data of this ResponseEnvelope.
        :type: ResultWrapper
        """

        if data is not None:
            if not isinstance(data, ResultWrapper):
                raise TypeError("Invalid type for `data`, type has to be `ResultWrapper`")

        self._data = data

    @property
    def more(self):
        # type: () -> object
        """Gets the more of this ResponseEnvelope.

        Additional endpoint specific information

        :return: The more of this ResponseEnvelope.
        :rtype: object
        """
        return self._more

    @more.setter
    def more(self, more):
        # type: (object) -> None
        """Sets the more of this ResponseEnvelope.

        Additional endpoint specific information

        :param more: The more of this ResponseEnvelope.
        :type: object
        """

        if more is not None:
            if not isinstance(more, object):
                raise TypeError("Invalid type for `more`, type has to be `object`")

        self._more = more

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseEnvelope):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_virtual_license import AnalyticsVirtualLicense
from bitmovin_api_sdk.models.analytics_virtual_license_request import AnalyticsVirtualLicenseRequest
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.analytics.virtual_licenses.analytics_virtual_license_list_query_params import AnalyticsVirtualLicenseListQueryParams


class VirtualLicensesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(VirtualLicensesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, analytics_virtual_license_request, **kwargs):
        # type: (AnalyticsVirtualLicenseRequest, dict) -> AnalyticsVirtualLicense
        """Create Analytics Virtual License

        :param analytics_virtual_license_request: Analytics Virtual License to be created
        :type analytics_virtual_license_request: AnalyticsVirtualLicenseRequest, required
        :return: Created Analytics Virtual license
        :rtype: AnalyticsVirtualLicense
        """

        return self.api_client.post(
            '/analytics/virtual-licenses',
            analytics_virtual_license_request,
            type=AnalyticsVirtualLicense,
            **kwargs
        )

    def delete(self, virtual_license_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Analytics Virtual License

        :param virtual_license_id: Virtual License id
        :type virtual_license_id: string_types, required
        :return: Id of deleted Virtual License
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/analytics/virtual-licenses/{virtual_license_id}',
            path_params={'virtual_license_id': virtual_license_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, virtual_license_id, **kwargs):
        # type: (string_types, dict) -> AnalyticsVirtualLicense
        """Analytics Virtual License

        :param virtual_license_id: Virtual license id
        :type virtual_license_id: string_types, required
        :return: Analytics Virtual License
        :rtype: AnalyticsVirtualLicense
        """

        return self.api_client.get(
            '/analytics/virtual-licenses/{virtual_license_id}',
            path_params={'virtual_license_id': virtual_license_id},
            type=AnalyticsVirtualLicense,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AnalyticsVirtualLicenseListQueryParams, dict) -> AnalyticsVirtualLicense
        """List Analytics Virtual Licenses

        :param query_params: Query parameters
        :type query_params: AnalyticsVirtualLicenseListQueryParams
        :return: List of Analytics Virtual licenses
        :rtype: AnalyticsVirtualLicense
        """

        return self.api_client.get(
            '/analytics/virtual-licenses',
            query_params=query_params,
            pagination_response=True,
            type=AnalyticsVirtualLicense,
            **kwargs
        )

    def update(self, virtual_license_id, analytics_virtual_license_request, **kwargs):
        # type: (string_types, AnalyticsVirtualLicenseRequest, dict) -> AnalyticsVirtualLicense
        """Update Analytics Virtual License

        :param virtual_license_id: Virtual license id
        :type virtual_license_id: string_types, required
        :param analytics_virtual_license_request: Analytics Virtual License details to be updated
        :type analytics_virtual_license_request: AnalyticsVirtualLicenseRequest, required
        :return: Updated Analytics Virtual License
        :rtype: AnalyticsVirtualLicense
        """

        return self.api_client.put(
            '/analytics/virtual-licenses/{virtual_license_id}',
            analytics_virtual_license_request,
            path_params={'virtual_license_id': virtual_license_id},
            type=AnalyticsVirtualLicense,
            **kwargs
        )
